@@ -1,14 +1,12 @@
 import fitz
 import datetime
 
-from fitz.fitz import PaperSize
-
 # This dict is specific to pyMuPDF.
 # Keys can only be : format, encryption, title, author, subject, keywords, creator, producer, creationDate, modDate
 
 document = {
-    "creationDate": fitz.getPDFnow(),  # current timestamp
-    "modDate": fitz.getPDFnow(),  # current timestamp
+    "creationDate": fitz.get_pdf_now(),  # current timestamp
+    "modDate": fitz.get_pdf_now(),  # current timestamp
     "creator": "Python mdfpdf package: https://pypi.org/project/mdpdf",
     "producer": "PyMuPDF library: https://pypi.org/project/PyMuPDF",
     "title": None,
